from typing import Literal
from cyberchipped.utilities.openai import get_client


async def ai_vision(
    user_prompt: str,
    base64_image: str,
    mime_type: Literal[
        "image/png", "image/jpeg", "image/gif", "image/webp"
    ] = "image/png",
):
    client = get_client()
    response = await client.chat.completions.create(
        model="gpt-4-vision-preview",
        messages=[
            {
                "role": "user",
                "content": [
                    {"type": "text", "text": user_prompt},
                    {
                        "type": "image_url",
                        "image_url": {"url": f"data:{mime_type};base64,{base64_image}"},
                    },
                ],
            }
        ],
        max_tokens=300,
    )
    return response.choices[0].message.content



from .settings import settings

from .assistants import Assistant

from .components import ai_fn, ai_model, ai_listen, ai_speak, ai_vision, ai_image

__all__ = [
    "ai_fn",
    "ai_model",
    "ai_listen",
    "ai_speak",
    "ai_vision",
    "ai_image",
    "settings",
    "Assistant",
]



from typing import Literal
from cyberchipped.utilities.openai import get_client


async def ai_image(
    user_prompt: str,
    model: Literal["dall-e-2", "dall-e-3"] = "dall-e-3",
    n: int = 1,
    quality: Literal["hd", "standard"] = "standard",
    response_format: Literal["url", "b64_json"] = "url",
    size: Literal[
        "256x256", "512x512", "1024x1024", "1792x1024", "1024x1792"
    ] = "1024x1024",
    style: Literal["standard", "vivid"] = "vivid",
    user: str = "",
):
    client = get_client()
    response = await client.images.generate(
        prompt=user_prompt,
        model=model,
        n=n,
        quality=quality,
        response_format=response_format,
        size=size,
        style=style,
        user=user,
    )
    return response.data



from typing import Literal
from cyberchipped.utilities.openai import get_client


async def ai_speak(
    input: str,
    model: Literal["tts-1", "tts-1-hd"] = "tts-1",
    voice: Literal["alloy", "echo", "fable", "onyx", "nova", "shimmer"] = "nova",
    response_format: Literal["aac", "opus", "flac"] = "aac",
):
    client = get_client()
    response = await client.audio.speech.create(
        input=input,
        model=model,
        voice=voice,
        response_format=response_format,
    )
    return response.response.iter_bytes()



from cyberchipped.components.ai_function import ai_fn as fn
from cyberchipped.components.ai_model import ai_model as model
from cyberchipped.components.ai_listen import listen

__all__ = ["fn", "model", "listen"]



from .ai_function import ai_fn, AIFunction
from .ai_model import ai_model
from .prompt import prompt_fn, PromptFunction
from .ai_listen import ai_listen
from .ai_speak import ai_speak
from .ai_vision import ai_vision
from .ai_image import ai_image

__all__ = [
    "ai_fn",
    "ai_model",
    "prompt_fn",
    "AIFunction",
    "PromptFunction",
    "ai_listen",
    "ai_speak",
    "ai_vision",
    "ai_image",
]



from typing import Literal
from cyberchipped.utilities.openai import get_client
from openai._types import FileTypes


async def ai_listen(
    file: FileTypes,
    response_format: Literal["json", "text", "srt", "verbose_json", "vtt"] = "text",
):
    client = get_client()
    response = await client.audio.transcriptions.create(
        file=file,
        model="whisper-1",
        response_format=response_format,
    )
    return response
